# Changelog

All notable changes to this project will be documented in this file.

## [0.7.0] - 2026-03-03

### Build & CI

- Add automated changelog and release workflows ([#9](https://github.com/scikit-hep/hypothesis-awkward/pull/9)) ([5bd691b](https://github.com/scikit-hep/hypothesis-awkward/commit/5bd691b7a624a65ff1c4fb7453843b6a1c9ac73a))
- Add conventional commit prefixes to Dependabot PR titles ([#10](https://github.com/scikit-hep/hypothesis-awkward/pull/10)) ([45ea7b0](https://github.com/scikit-hep/hypothesis-awkward/commit/45ea7b05d9dd6c40043e3a892935891fa7303f73))
## [0.0.2] - 2025-11-19
